@@ -1,6 +1,8 @@
-package bar;
+package t::lib::bar;
 
-use base 'foo';
+our $VERSION = 1;
+
+use base 't::lib::foo';
 
 use Method::Signatures::WithDocumentation;
 
